'use client'

import { useState } from 'react'
import { FiSave } from 'react-icons/fi'
import { useRouter } from 'next/navigation'
import DashboardLayout from '@/components/layout/DashboardLayout'
import { tableService } from '@/services/api'
import { useUser } from '@/contexts/UserContext'
import Modal from '@/components/ui/Modal'
export default function AddTablePage() {
  const router = useRouter()
  const { user } = useUser()
  const [formData, setFormData] = useState({
    name: '',
  })
  const [loading, setLoading] = useState(false)
  const [error, setError] = useState<string | null>(null)
  const [success, setSuccess] = useState<string | null>(null)

  const handleInputChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const { name, value } = e.target
    setFormData(prev => ({
      ...prev,
      [name]: value
    }))
  }

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault()
    setLoading(true)
    setError(null)

    try {
      await tableService.create(formData.name, user?.token || '')
      setSuccess('Masa başarıyla eklendi yönlendiriliyorsunuz...')
      setTimeout(() => {
        router.push('/dashboard/tables')
      }, 1500)

    } catch (err) {
      setError('Masa eklenirken bir hata oluştu')
      console.error('Masa ekleme hatası:', err)
    } finally {
      setLoading(false)
    }
  }

  return (
    <DashboardLayout>
      <div className="w-full mx-auto">
        <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm rounded-3xl shadow-lg 
                     border border-slate-200/50 dark:border-slate-700/50">
          <div className="p-6 border-b border-slate-200/50 dark:border-slate-700/50">
            <h2 className="text-xl font-bold text-slate-800 dark:text-white">
              Yeni Masa Ekle
            </h2>
            <p className="text-sm text-slate-500 dark:text-slate-400 mt-1">
              Yeni bir masa eklemek için formu doldurun
            </p>
          </div>

          <form onSubmit={handleSubmit} className="p-6 space-y-6">
            {error && (
              <div className="p-4 bg-red-50 text-red-500 rounded-xl text-sm">
                {error}
              </div>
            )}

            <div>
              <label htmlFor="name" className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                Masa Adı
              </label>
              <input
                id="name"
                name="name"
                type="text"
                value={formData.name}
                onChange={handleInputChange}
                className="w-full px-4 py-2.5 rounded-xl border border-slate-200/50 dark:border-slate-700/50 
                         bg-white/50 dark:bg-slate-700/50 backdrop-blur-sm
                         text-slate-800 dark:text-white
                         focus:outline-none focus:ring-2 focus:ring-fuchsia-500/50
                         transition-all"
                placeholder="Örn: Masa 1"
                required
              />
            </div>

            <div className="flex justify-end">
              <button
                type="submit"
                disabled={loading}
                className="px-6 py-2.5 text-sm font-medium text-white
                       bg-gradient-to-r from-fuchsia-500 to-purple-600
                       rounded-xl hover:opacity-90 transition-all
                       disabled:opacity-50 disabled:cursor-not-allowed
                       flex items-center gap-2"
              >
                <FiSave className="w-4 h-4" />
                {loading ? 'Kaydediliyor...' : 'Kaydet'}
              </button>
            </div>
          </form>
        </div>
      </div>
      {success && (
        <Modal
          isOpen={!!success}
          title="Başarılı"
          message={success}
          onClose={() => setSuccess(null)}
        />
      )}
      {error && (
        <Modal
          isOpen={!!error}
          title="Hata"
          message={error}
          onClose={() => setError(null)}
        />
      )}
    </DashboardLayout>
  )
} 